[
https://issues.apache.org/jira/browse/IGNITE-1613?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=14943388#comment-14943388
]
Pavel Tupitsyn commented on IGNITE-1613:
-----------------------------------------
Guid:
* Since we write all 16 bytes separately, bottleneck is mostly in
EnsureWriteCapacityAndShift and such.
* To write Guid in a single operation and avoid array allocations on heap, I've
used structs with sequential layout. This way guid conversion has very little
overhead. Newly added benchmark shows 25% improvement.
> Platform .Net: Investigate Guid/DateTime/String interoperability with Java
> --------------------------------------------------------------------------
>
> Key: IGNITE-1613
> URL: https://issues.apache.org/jira/browse/IGNITE-1613
> Project: Ignite
> Issue Type: Task
> Components: interop
> Affects Versions: ignite-1.5
> Reporter: Pavel Tupitsyn
> Assignee: Pavel Tupitsyn
> Fix For: ignite-1.5
>
>
> Currently in .Net we:
> * write Guid and DateTime in Java format
> * calculate string hash code for field names with Java algorithm on each call
> Need to investigate if the following makes sense:
> 1) In .Net always write Guid and DateTime in native .Net format as fast as
> possible; Make Java understand that format. (Not every Guid written in .Net
> will be read in Java, so we can win time).
> 2) Cache string hashcodes somehow.
--
This message was sent by Atlassian JIRA
(v6.3.4#6332)